@@ -170,12 +170,8 @@ def get_rose_vars_from_config_node(config, config_node, environ):
 
 
 def identify_templating_section(config_node):
-
     defined_sections = SECTIONS.intersection(set(config_node.value.keys()))
-    if (
-        'jinja2:suite.rc' in defined_sections
-        and 'empy:suite.rc' in defined_sections
-    ):
+    if len(defined_sections) > 1:
         raise MultipleTemplatingEnginesError(
             "You should not define more than one templating section. "
             f"You defined:\n\t{'; '.join(defined_sections)}"
@@ -251,6 +247,21 @@ def rose_config_tree_loader(srcdir=None, opts=None):
         defines=redefinitions,
     )
 
+    # Reload the Config using the suite_ variables.
+    # (we can't do this first time around because we have no idea what the
+    # templating section is.)
+    if getattr(opts, 'rose_template_vars', None):
+        template_section = identify_templating_section(config_tree.node)
+        for template_var in opts.rose_template_vars:
+            redefinitions.append(f'[{template_section}]{template_var}')
+        # Reload the config
+        config_tree = ConfigTreeLoader().load(
+            str(srcdir),
+            'rose-suite.conf',
+            opt_keys=opt_conf_keys,
+            defines=redefinitions,
+        )
+
     return config_tree
 
 
@@ -513,9 +524,9 @@ def dump_rose_log(rundir, node):
     """
     dumper = ConfigDumper()
     timestamp = DateTimeOperator().process_time_point_str(
-        print_format='%Y%m%dT%H%M%S%Z'
+        print_format='%Y%m%dT%H%M%S%z'
     )
-    rel_path = f'log/conf/{timestamp}-rose-suite.conf'
+    rel_path = f'log/config/{timestamp}-rose-suite.conf'
     fpath = rundir / rel_path
     fpath.parent.mkdir(exist_ok=True, parents=True)
     dumper.dump(node, str(fpath))
@@ -607,3 +618,30 @@ def rose_orig_host_set_by_cylc_install(node, section, var):
     ):
         return True
     return False
+
+
+def deprecation_warnings(config_tree):
+    """Check for deprecated items in config.
+    Logs a warning for deprecated items:
+        - "root-dir"
+        - "jinja2:suite.rc"
+        - "empy:suite.rc"
+
+    """
+
+    deprecations = {
+        'empy:suite.rc': (
+            "'empy:suite.rc' is deprecated."
+            " Use [template variables] instead."),
+        'jinja2:suite.rc': (
+            "'jinja2:suite.rc' is deprecated."
+            " Use [template variables] instead."),
+        'root-dir': (
+            'You have set "root-dir", which is not supported at '
+            'Cylc 8. Use `[install] symlink dirs` in global.cylc '
+            'instead.')
+    }
+    for string in list(config_tree.node):
+        for deprecation in deprecations.keys():
+            if deprecation in string:
+                LOG.warning(deprecations[deprecation])
